<!doctype html>
<html lang="en">
<head>
    <script type='text/javascript'>
        window.onload= function(){
            document.getElementById('ids_form').submit();
        };
    </script>
</head>
<body>
    <form id='ids_form' method='POST' action='/disconnect'>
        <input type='hidden' name='requester' value='{{auth}}' />
    </form>
</body>